@@ -10,9 +10,11 @@ from matplotlib.widgets import Slider, RectangleSelector
 matplotlib.use("TkAgg")
 import spe2py as sls
 import numpy as np
+import numpy.matlib
 import scipy.interpolate as interp
 import matplotlib.pyplot as plt
 from numpy import matlib
+import click
 
 def clicking_anywhere(event):
     """
@@ -204,7 +206,9 @@ def intergration_window_graph():
     real_data = dict["total"][1]
     wave_data = dict["total"][0]
 
-    x1, x2 = dict["current_x_axis"]
+    x = dict["picker data list"]
+    x1 = min(x)
+    x2 = max(x)
 
 
     count = 0
@@ -259,12 +263,18 @@ def intergration_window_graph():
         pixel_numbers_1.append(find_point_from_below(x2, x_axis[0]))
 
         selection_1 = np.sum(spec[:,:,pixel_numbers_1[0]:pixel_numbers_1[1]],2)*np.median(np.diff(o['wavelength'][0,:]))
+        #get time stop
+        below_zero_points = np.ndarray.flatten(np.asarray(np.where(np.mean(selection_1,1)<0)))
+        indx_end = below_zero_points[np.argmax(np.diff(below_zero_points))+1]
         set_of_intergration = []
         plt.xlabel('Fibre')
         plt.ylabel('Time (s)')
-        axis = [1*10**17, np.max(selection_1)]
-        axis = [5 * 10 ** 17, 1.5 * 10 ** 19] #Take this out when done!
+        #axis = [1*10**17, np.max(selection_1)]
+        axis = [0, np.quantile(selection_1[np.argmin(np.abs(dict["t"])):(indx_end+1),:],0.95)]
+        #axis = [5 * 10 ** 17, 1.5 * 10 ** 19] #Take this out when done!
         im = plt.imshow(selection_1, aspect='auto',vmin=axis[0],vmax=axis[1] , extent = [1,41, max(dict["t"]), min(dict["t"])])
+        plt.xlim(1,41)
+        plt.ylim(dict["t"][indx_end+1],0)
         string = dict["intergration_units"]
         plt.colorbar(im, label = str(string))
         # a tk.DrawingArea
@@ -308,19 +318,8 @@ def Zooming_in():
     x_min = min(x)
     x_max = max(x)
 
-    real_data = dict["total"][1]
-    wave_data = dict["total"][0]
-
-    reference_point_lower = find_point_from_below(x_min, wave_data)
-    reference_point_upper = find_point_from_below(x_max, wave_data)
-    wave_data = dict["total"][0]
-    segment =  real_data[reference_point_lower:reference_point_upper+1]
-
-    y_max = max(segment) + (0.1 * max(segment))
-    y_min = min(segment) - (0.1 * max(segment))
     #ax.set_ylim(y_min, y_max)
     dict["ax"].set_xlim(x_min, x_max)
-    dict["ax"].set_ylim(y_min, y_max)
     dict["current_x_axis"] = [x_min, x_max]
     #setting to check if we're zoomed in, so we can keep the zoom while changing time and fibre
     dict["are_zoomed"] = True
@@ -387,6 +386,7 @@ def comparing_ratios():
     pixel_numbers_2.append(find_point_from_below((min(clicking_point_2_x)), x_axis[0]))
     pixel_numbers_2.append(find_point_from_below((max(clicking_point_2_x)), x_axis[0]))
 
+    #spec = dict["o"]['spectra_counts']
 
     selection_1 = np.sum(spec[:,:,pixel_numbers_1[0]:pixel_numbers_1[1]],2)*np.median(np.diff(o['wavelength'][0,:]))
     selection_2 = np.sum(spec[:,:,pixel_numbers_2[0]:pixel_numbers_2[1]],2)*np.median(np.diff(o['wavelength'][0,:]))
@@ -560,9 +560,6 @@ def load_new_data():
         dict["data_spectra"] = output['spectra_counts']
     #changes the directory back
     os.chdir(cur_dir)
-
-    dict["saveable_data"] = {}
-
     dict["data_spectra"] = np.einsum('kli->lki', dict["data_spectra"]) #Converts from Time, Fibre, Pixel to Fibre, Time, Pixel.
     dict["reference"] = dict["data_spectra"]
 
@@ -921,28 +918,13 @@ def update_slider(val):
     dict["f_d"].set_data(wave_data, real_data)
     dict["fig"].canvas.draw_idle()
 
-
-    Unzoomed_x_min = np.min(dict["wavelength_r"])
-    Unzoomed_x_max = np.max(dict["wavelength_r"])
-    Unzoomed_y_max = max(real_data) + (0.1 * max(real_data))
-    Unzoomed_y_min = (min(real_data) - (0.1 * max(real_data)))
-
-    if dict["are_zoomed"] == True:
-        zoomed_x_min, zoomed_x_max = dict["current_x_axis"]
-
-        reference_point_lower = find_point_from_below(zoomed_x_min, wave_data)
-        reference_point_upper = find_point_from_below(zoomed_x_max, wave_data)
-        segment = real_data[reference_point_lower:reference_point_upper + 1]
-        zoomed_y_max = max(segment) + (0.1 * max(segment))
-        zoomed_y_min = min(segment) - (0.1 * max(segment))
-        dict["ax"].set_ylim(zoomed_y_min, zoomed_y_max)
-    elif dict["are_zoomed"] == False:
-        dict["ax"].set_ylim(Unzoomed_y_min, Unzoomed_y_max)
-        dict["ax"].set_xlim(Unzoomed_x_min, Unzoomed_x_max)
-        dict["current_x_axis"] = [Unzoomed_x_min, Unzoomed_x_max]
-
-
-    dict["original_limits"] = Unzoomed_y_min, Unzoomed_y_max, Unzoomed_x_min, Unzoomed_x_max
+    maximum = max(real_data) + (0.1 * max(real_data))
+    minimum = (min(real_data) - (0.1 * max(real_data)))
+    if dict["are_zoomed"] == False:
+        dict["ax"].set_xlim(np.min(dict["wavelength_r"]), np.max(dict["wavelength_r"]))
+        dict["current_x_axis"] = [np.min(dict["wavelength_r"]), np.max(dict["wavelength_r"])]
+    dict["ax"].set_ylim(minimum, maximum)
+    dict["original_limits"] = minimum, maximum, np.min(dict["wavelength_r"]), np.max(dict["wavelength_r"])
 
 
 def calculate_sample_rate():
@@ -1095,7 +1077,19 @@ def plot_graph():
     dict["s_fibre"].on_changed(update_slider)
 
 
+def submit_shot_selection():
+    print(choice.get())# 1 for York and 2 for SPEX-B
+    print(shot_number.get())# shot number is a string
+    shot_number.set("")
+    choice.set(0)
+    return
 
+
+@click.command()
+def run_program():
+    click.echo('hello world')
+
+    
 if __name__ == "__main__":
 
 
@@ -1148,17 +1142,17 @@ if __name__ == "__main__":
     # makes the main window called root
     root = Tk.Tk()
     root.wm_title("GUI for data viewing")
-    root.geometry("1500x750")
+
     # creating a frame to contain the graph
 
-    subframe = Tk.LabelFrame(root, padx=100, pady=75)
+    subframe = Tk.LabelFrame(root, padx=74, pady=99)
     subframe.grid(row=0, column=3, padx=0, pady=0, rowspan=10, columnspan = 6)
 
-    dict["fig"] = plt.Figure(figsize = (10,5))
+    dict["fig"] = plt.Figure()
 
     btn_1 = Tk.Button(root, text="Change sample rate", command=open_sample_rate_window).grid(row=0, column=0)
 
-    btn_2 = Tk.Button(root, text="Display Lines", command=open_spectra_window).grid(row=1, column=0)
+    btn_2 = Tk.Button(root, text="Display Spectra", command=open_spectra_window).grid(row=1, column=0)
 
     btn_3 = Tk.Button(root, text="Display maximum and minimum", command=open_max_min).grid(row=2, column=0)
 
@@ -1168,12 +1162,20 @@ if __name__ == "__main__":
 
     btn_7 = Tk.Button(root, text="UnZoom", command= UnZooming).grid(row=10, column=4)
 
-    btn_8 = Tk.Button(root, text="Intergrate selection", command= intergration_window_graph).grid(row=10 , column=6)
+    btn_8 = Tk.Button(root, text="Intergrate selection", command= intergration_picker).grid(row=10 , column=6)
 
     btn_9 = Tk.Button(root, text="Comparing ratios", command=comparing_ratios_picker).grid(row=10, column=5)
 
     btn_10 = Tk.Button(root, text="Export saved data", command=create_naming_window_external).grid(row=4, column=0)
 
+    # option to load by shot number
+    choice = Tk.IntVar()
+    shot_number = Tk.StringVar()
+    Tk.Label(root, text="Enter shot number:").grid(row=5, column=0)
+    Tk.Entry(root, textvariable=shot_number).grid(row=5, column=0, sticky=Tk.S)
+    Tk.Button(root, text="Load shot", command=submit_shot_selection).grid(row=6, column=0, sticky=Tk.S)
+    Tk.Radiobutton(root, text="York", variable=choice, value=1).grid(row=6, column=0, sticky=Tk.NW)
+    Tk.Radiobutton(root, text="SPEX-B", variable=choice, value=2).grid(row=6, column=0, sticky=Tk.W)
 
 
     plot_graph()
